'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var gpaBuilders = require('../gpaBuilders.cjs');
var Operation = require('../../../types/Operation.cjs');

// -----------------
// Operation
// -----------------
const Key = 'FindNftsByUpdateAuthorityOperation';

/**
 * Finds multiple NFTs and SFTs by a given update authority.
 *
 * ```ts
 * const nfts = await metaplex
 *   .nfts()
 *   .findAllByUpdateAuthority({ updateAuthority };
 * ```
 *
 * @group Operations
 * @category Constructors
 */
const findNftsByUpdateAuthorityOperation = Operation.useOperation(Key);

/**
 * @group Operations
 * @category Types
 */

/**
 * @group Operations
 * @category Inputs
 */

/**
 * @group Operations
 * @category Outputs
 */

/**
 * @group Operations
 * @category Handlers
 */
const findNftsByUpdateAuthorityOperationHandler = {
  handle: async (operation, metaplex, scope) => {
    const {
      updateAuthority
    } = operation.input;
    const gpaBuilder = new gpaBuilders.MetadataV1GpaBuilder(metaplex, metaplex.programs().getTokenMetadata(scope.programs).address);
    const mints = await gpaBuilder.selectMint().whereUpdateAuthority(updateAuthority).getDataAsPublicKeys();
    scope.throwIfCanceled();
    const nfts = await metaplex.nfts().findAllByMintList({
      mints
    }, scope);
    scope.throwIfCanceled();
    return nfts.filter(nft => nft !== null);
  }
};

exports.findNftsByUpdateAuthorityOperation = findNftsByUpdateAuthorityOperation;
exports.findNftsByUpdateAuthorityOperationHandler = findNftsByUpdateAuthorityOperationHandler;
//# sourceMappingURL=findNftsByUpdateAuthority.cjs.map
